## What's Changed

1. 修复：部分情况下，MCP、配置文件的代码编辑器一直显示 `loading...` 的问题(bump monaco-editor version to 0.54.0)。
2. 新增：重构创建消息平台时的流程及一些 UI 优化 ([#3102](https://github.com/AstrBotDevs/AstrBot/issues/3102))
3. 新增：全新的自带知识库功能。
4. 新增：插件支持显示可读名称和 Logo。
5. 修复： dashboard.enable 配置未生效。
6. 新增：Misskey 适配器支持文件上传、投票内容感知功能和重构部分代码 ([#2986](https://github.com/AstrBotDevs/AstrBot/issues/2986))
7. 新增：优化 Misskey 适配器的通知和聊天消息处理，改进 @用户提及逻辑 ([#3075](https://github.com/AstrBotDevs/AstrBot/issues/3075))
8. 新增：QQ 官方机器人增加沙盒模式选项，让本地部署能跳过 IP 白名单验证 ([#3087](https://github.com/AstrBotDevs/AstrBot/issues/3087))
9. 新增：Satori 添加对合并转发消息功能的支持 ([#3050](https://github.com/AstrBotDevs/AstrBot/issues/3050))
10. 修复：人格预设对话的重复注入 ([#3088](https://github.com/AstrBotDevs/AstrBot/issues/3088))
11. 新增：适配第三方 Gemini 思考片段过滤 ([#3139](https://github.com/AstrBotDevs/AstrBot/issues/3139))
12. 重构：从主模块和依赖项中移除 Google 搜索引擎集成 ([#3154](https://github.com/AstrBotDevs/AstrBot/issues/3154))
